// Nave.java

package dBattNav.dNave;

import  dBattNav.dCoppia.Coppia;

/* - [ Layout delle navi ] ------------------------------------------------- *
 *                                                                           *
 * [*]              -   1 componente                                         *
 *                                                                           *
 * [*][*]           -   2 componenti                                         *
 *                                                                           *
 * [*][*][*]        -   3 componenti                                         *
 *                                                                           *
 * [*][*][*][*]     -   4 componenti                                         *
 *                                                                           *
 * ------------------------------------------------------------------------- */

/** classe Nave per la gestione di una nave nel piano
@see dBattNav.dCoppia.Coppia
@see dBattNav.BattNav */
public class Nave {
    private Coppia coord;       //coordinate dell'inizio della nave
    private boolean status[];   //vettore contenente lo stato delle componenti -
                                //della nave (true=colpito; false=non colpito)

    /** costruttore di inizializzazione
    @param c coppia di coordinate della componente iniziale
    @param l numero di componenti della nave
    */
    public Nave (Coppia c,int l) {
        coord = new Coppia(c.getX(),c.getY()); //impostazione delle coordinate
        status=new boolean[l];
        for (int i=0;i<status.length;i++)
            status[i]=false;
    }//Nave

    /** fuoco ritorna l'esito di un colpo
    @param x coordinata x del colpo
    @param y coordinata y del colpo
    @return String esito <acqua|affondato|colpito|>
    */
    public String fuoco (Coppia c) {
        if (coord.getY()==c.getY())              
        for (int i=0;i<status.length;i++)
            if (coord.getX()+i==c.getX()) {
                status[i]=true;
                for(int j=0;j<status.length;j++)//controllo affondamento
                    if(status[j]==false)
                        return "colpito";
                return "affondato";
            }//if
        return "acqua";  
    }//fuoco
 
    /**metodo che controlla se la nave  affondata
    @return true se la nave  affondata false se la nave non  affondata
    */
    public boolean controllo(){    
        for(int i=0;i<status.length;i++)
            if(status[i]==false)
                return false;
        return true;
    }//controllo
    
    /** getX restituisce la coordinata x della componente iniziale della nave
    @return x
    */
    public int getX () {
        return coord.getX();
    }//getX

    /** getY restituisce la coordinata x della componente iniziale della nave
    @return y
    */
    public int getY () {
        return coord.getY();
    }//getY

    /** getL restituisce la lunghezza della nave
    @return lunghezza della nave
    */
    public int getL () {
        return status.length;
    }//getL

    /** getCoords restituisce le coordinate della componente iniziale della nave
    @return coord coppia delle coordinate della componente iniziale della nave
    */
    public Coppia getCoords () {
        return coord;
    }//getCoords

    /** getStatus restituisce il vettore degli stati delle componenti della nave
    @return status
    */
    public boolean[] getStatus () {
        return status;
    }//getL

    /** toString
    @return stato della nave
    */
    public String toString () {
        for (int i=0;i<status.length;i++)
            if (status[i]==false)
                return "non affondata";
        return "affondata";
    }//toString
}//Nave
