// Portaerei.java

package dBattNav.dNave;

import  dBattNav.dCoppia.Coppia;

/* - [ Layout della portaerei ] -------------------------------------------- *
 *                                                                           *
 * [*]                                                                       *
 * [*]              -   1 componente                                         *
 *                                                                           *
 * [*]                                                                       *
 * [*][*]           -   2 componenti                                         *
 *                                                                           *
 * [*]                                                                       *
 * [*][*][*]        -   3 componenti                                         *
 *                                                                           *
 * [*]                                                                       *
 * [*][*][*][*]     -   4 componenti                                         *
 *                                                                           *
 * ------------------------------------------------------------------------- */

/** classe Portaerei per la gestione di una nave portaerei nel piano
@see dBattNav.dCoppia.Coppia
@see dBattNav.dNave.Nave
@see dBattNav.BattNav */
public class Portaerei extends Nave {
    private boolean pista;  //componente aggiuntiva della nave -
                            //(true=colpito; false=non colpito)

    /** costruttore di inizializzazione
    @param c coppia di coordinate della componente iniziale
    */
    public Portaerei (Coppia c,int l) {
        super(c,l);
        pista=false;
    }//Nave

    /** fuoco ritorna l'esito di un colpo
    @param x coordinata x del colpo
    @param y coordinata y del colpo
    @return String esito <acqua|affondato|colpito|gia' colpito>
    */
    public String fuoco (Coppia c) {
        String ris=super.fuoco(c);
        if (ris.equals("colpito")) //se ris e' uguale a colpito
            return ris;
        if ((c.getX()==super.getX()) && (c.getY()==super.getY()+1)) {
            pista=true;
            if (super.controllo())
                return "affondato";
            else 
                ris="colpito";   
        }//if
        if(ris.equals("affondato"))
            if(pista==false)
                return "colpito";
        return ris;      
    }//fuoco

    /**metodo che controlla se la portaerei  affondata
    @return true se la nave  affondata false se la nave non  affondata
    */
    public boolean controllo(){
        if(super.controllo())    
            if(pista==true)
                return true;
        return false;
    }//controllo

    /** getX restituisce la coordinata x della componente iniziale della nave
    @return x
    */
    public int getX () {
        return super.getX();
    }//getX

    /** getY restituisce la coordinata x della componente iniziale della nave
    @return y
    */
    public int getY () {
        return super.getY();
    }//getY

    /** getL restituisce la lunghezza della portaerei
    @return lunghezza della portaerei
    */
    public int getL () {
        return super.getL();
    }//getL

    /** getCoords restituisce le coordinate della componente iniziale della nave
    @return coord coppia delle coordinate della componente iniziale della nave
    */
    public Coppia getCoords () {
        return super.getCoords();
    }//getCoords

    /** getStatus restituisce il vettore degli stati delle componenti della nave
    @return s vettore componenti
    */
    public boolean[] getStatus () {
        boolean s1[]=super.getStatus();
        boolean s[]=new boolean[s1.length+1];
        s[0]=pista;
        for (int i=1;i<=s1.length;i++)
            s[i]=s1[i-1];
        return s;
    }//getStatus

    /** toString
    @return stato della nave
    */
    public String toString () {
        String ris=super.toString();
        if (ris.equals("affondata"))
            if (pista==true)
                return ris;
            else
                return "non affondata";
        return ris;
    }//toString
}//Portaerei
