// Console.java

package dUtil;

import  java.io.InputStream;
import  java.io.InputStreamReader;

/** metodi utili per l'uso della console a caratteri
@see InputStreamReader */
public class Console extends InputStreamReader {
    /** costruttore di inizializzazione
    @param in stream di input. */
    public Console(InputStream in) {
        super(in);
    }//Console

    /** stampa un prompt sullo schermo senza andare a capo
    @param prompt stringa da stampare */
    private static void printPrompt(String prompt) {
        System.out.print(prompt);
        System.out.flush();
    }//printPrompt

    /** legge una stringa terminata da un NEW-LINE
    @return la stringa letta senza il NEW-LINE */
    public static String readLine() {
        int ch;
        String r="";
        boolean done=false;
        while (!done)
            try {
                ch=System.in.read();
                if (ch<0 || (char)ch=='\n')
                    done=true;
                else if ((char)ch!='\r')
                    r=r+(char) ch;
            }catch(java.io.IOException e) {
                done=true;
            }//try catch
        return r;
    }//readLine

    /** legge una stringa terminata da un NEW-LINE stampando un prompt
    @param prompt la stringa da stampare
    @return la stringa letta senza il NEW-LINE */
    public static String readLine(String prompt) {
        printPrompt(prompt);
        return readLine();
    }//readLine

    /** legge un intero stampando un prompt
    @param prompt stringa da stampare
    @return la stringa letta convertita in un intero */
    public static int readInt(String prompt) {
        while(true) {
            printPrompt(prompt);
            try {
                return Integer.valueOf(readLine().trim()).intValue();
            }catch(NumberFormatException e) {
                System.out.println("Non e' un intero, riprova!");
            }//try catch
        }//while
    }//readInt

    /** legge un intero
    @return la stringa letta convertita in un intero */
    public static int readInt() {
        return readInt("");
    }//readInt

    /** legge un double stampando un prompt
    @param prompt stringa da stampare
    @return la stringa letta convertita in un double */
    public static double readDouble(String prompt) {
        while(true) {
            printPrompt(prompt);
            try {
                return Double.parseDouble(readLine().trim());
            }catch(NumberFormatException e) {
                System.out.println("Non e' un numero decimale, riprova!");
            }//try catch
        }//while
    }//readDouble

    /** legge un double
    @return la stringa letta convertita in un double */
    public static double readDouble() {
        return readDouble("");
    }//readDouble

    /** cancella lo schermo
    */
    public static void clrscr () {
        for (int i=0;i<50;i++)
            System.out.println("\n\n");
    }//clrscr

    /** chiede la pressione di un tasto e cancella lo schermo
    */
    public static void pause () {
        Console.readLine("\nPremi un tasto per continuare...");
        clrscr();
    }//pause

    /** stampa un titolo formattato
    */
    public static void printHeader (String title) {
        System.out.println("\n-------------------------------------------------------------------");
        System.out.println("- "+title);
        System.out.println("-------------------------------------------------------------------");
    }//printHeader

    /** stampa un sotto titolo formattato 
    */
    public static void printSubHeader (String title) {
        System.out.println("- "+title);
        System.out.println("-------------------------------------------------------------------");
    }//printSubHeader
}//Console
